import math


def estimate_r(midpoint):
    """
    Gets the estimate of r based on the supplied value of midpoint
    :param midpoint: int or float - the current estimate of r
    :return: float the current value of the equation
    """
    return midpoint * midpoint * math.pi - 1


def calculate_intersection(precision):
    """
    Calculates the number r such that r * r * pi - 1 = 0
    :param precision: the number of decimal places to calculate to - (must be an integer in the range 1 - 16).
    :return: a floating point number.
    """

    lower = 0
    upper = 1
    midpoint = (upper + lower) / 2
    estimate = estimate_r(midpoint)
    tolerance = 10 ** (-1 * precision)

    # Continue running as long as the difference is greater than the required tolerance
    while abs(estimate) > tolerance:
        # If the mid point is too low, take the upper half of the interval
        if estimate < 0:
            lower = midpoint
        # Otherwise, take the lower half of the interval
        else:
            upper = midpoint

        # Update our midpoint and estimate
        midpoint = (upper + lower) / 2
        estimate = estimate_r(midpoint)

    return midpoint


print(calculate_intersection(6))
